@@ -1,7 +1,7 @@
 package App::picadata;
 use v5.14.1;
 
-our $VERSION = '1.23';
+our $VERSION = '1.24';
 
 use Getopt::Long qw(GetOptionsFromArray :config bundling);
 use Pod::Usage;
@@ -38,7 +38,7 @@ my %COLORS
 sub new {
     my ($class, @argv) = @_;
 
-    my $interactive = -t *STDOUT;
+    my $interactive = -t *STDOUT;                           ## no critic
     my $command = (!@argv && $interactive) ? 'help' : '';
 
     my $number = 0;
@@ -60,7 +60,7 @@ sub new {
     };
 
     my %cmd = abbrev
-        qw(convert count fields subfields sf explain validate build diff patch help version);
+        qw(convert count split fields subfields sf explain validate build diff patch help version);
     if ($cmd{$argv[0]}) {
         $command = $cmd{shift @argv};
         $command =~ s/^sf$/subfields/;
@@ -104,7 +104,7 @@ sub new {
         }
     }
 
-    $opt->{order} = 1 if $command =~ /(diff|patch)/;
+    $opt->{order} = 1 if $command =~ /(diff|patch|split)/;
 
     unless ($command) {
         if ($opt->{schema} && !$opt->{annotate}) {
@@ -113,16 +113,18 @@ sub new {
         elsif ($opt->{abbrev}) {
             $command = 'build';
         }
+        else {
+            $command = 'convert';
+        }
     }
-    $opt->{command} = $command || 'convert';
 
-    if ($opt->{command} =~ /validate|explain/ && !$opt->{schema}) {
+    if ($command =~ /validate|explain|fields|subfields/ && !$opt->{schema}) {
         if ($ENV{PICA_SCHEMA}) {
             $opt->{schema} = $ENV{PICA_SCHEMA};
         }
-        else {
-            $opt->{error} = $opt->{command}
-                . " requires an Avram Schema (via option -s or environment variable PICA_SCHEMA)";
+        elsif ($command =~ /validate|explain/) {
+            $opt->{error}
+                = "$command requires an Avram Schema (via option -s or environment variable PICA_SCHEMA)";
         }
     }
 
@@ -137,12 +139,14 @@ sub new {
         or $opt->{error} = "unknown serialization type: " . $opt->{from};
 
     $opt->{to} = $opt->{from}
-        if !$opt->{to} and $opt->{command} =~ /(convert|diff|patch)/;
+        if !$opt->{to} and $command =~ /(convert|split|diff|patch)/;
     if ($opt->{to}) {
         $opt->{to} = $TYPES{lc $opt->{to}}
             or $opt->{error} = "unknown serialization type: " . $opt->{to};
     }
 
+    $opt->{command} = $command;
+
     bless $opt, $class;
 }
 
@@ -193,17 +197,7 @@ sub run {
         exit;
     }
 
-    # initialize parser, writer, and schema builder
-    my $input = $self->{input};
-
-    if ($input->[0] eq '-') {
-        $input = *STDIN;
-        binmode $input, ':encoding(UTF-8)';
-    }
-
-    binmode *STDOUT, ':encoding(UTF-8)';
-
-    my $parser = pica_parser($self->{from}, $input->[0], bless => 1);
+    # initialize writer and schema builder
     my $writer;
     if ($self->{to}) {
         $writer = pica_writer(
@@ -213,6 +207,7 @@ sub run {
             annotate => $self->{annotate},
         );
     }
+    binmode *STDOUT, ':encoding(UTF-8)';
 
     my $builder
         = $command =~ /(build|fields|subfields|explain)/
@@ -224,7 +219,9 @@ sub run {
     my $stats   = {records => 0, holdings => 0, items => 0, fields => 0};
     my $invalid = 0;
 
-    while (my $record = $parser->next) {
+    my $process = sub {
+        my $record = shift;
+
         if ($command eq 'select') {
             say $_ for map {@{$record->match($_, split => 1) // []}} @pathes;
         }
@@ -261,6 +258,27 @@ sub run {
         $stats->{records}++;
 
         last if $number and $stats->{records} >= $number;
+    };
+
+    foreach my $in (@{$self->{input}}) {
+        if ($in eq '-') {
+            $in = *STDIN;
+            binmode $in, ':encoding(UTF-8)';
+        }
+        else {
+            die "File not found: $in\n" unless -e $in;
+        }
+
+        my $parser = pica_parser($self->{from}, $in, bless => 1);
+
+        while (my $record = $parser->next) {
+            if ($command eq 'split') {
+                $process->($_) for $record->split;
+            }
+            else {
+                $process->($record);
+            }
+        }
     }
 
     $writer->end() if $writer;
